#ifndef __neoConnectionEvent_H__
#define __neoConnectionEvent_H__

#include <boost/shared_ptr.hpp>

namespace neo {
namespace cca {
namespace ports {

/** The four stages of the connection process that others
 * may need to be notified of.
 */
enum EventType {
    Error = -1,            // Someone got a bogus event object somehow.
    ALL = 0,               // Component wants to receive all event notices.
                           // ALL itself never received.
    ConnectPending = 1,    // A connection is about to be attempted.
    Connected = 2,         // A connection has been made.
    DisconnectPending = 3, // A disconnection is about to be attempted.
    Disconnected = 4,      // A disconnection has been made.
};
		

/** An event passed around when connection activities occur.
 * It is handled with a shared pointer.
 */
class ConnectionEvent {
 public:
	
  /** obligatory vdtor */
  virtual ~ConnectionEvent() {}

  /** return the event type. */
  virtual enum EventType getEventType()= 0;

  /** Get the properties of the affected Port.
   * Among these are:
   * "cca.portName" (string),
   * "cca.portType" (string),
   * "ABLE_TO_PROXY" (bool),
   * "MAX_CONNECTIONS" (int),
   * "MIN_CONNECTIONS" (int).
   */
  virtual TypeMap_shared getPortInfo()= 0;
};

/** ConnectionEvents are always seen as shared_ptr objects of this sort. */
typedef boost::shared_ptr< ConnectionEvent > ConnectionEvent_shared;

}  // end namespace ports
}  // end namespace cca
}  // end namespace neo
#endif // __neoConnectionEvent_H__
