#ifndef ServiceRegistry_hh_seen
#define ServiceRegistry_hh_seen
namespace neo {
namespace cca {
namespace ports {


//===================================================================
/**NOT YET DEFINED IN CCA.SIDL: 
 * ServiceRegistry is a Port that is primordially provided by the framework
 * and can be fished out by a component wishing to provide service Ports. 
 * Each binding has to provide a wrapping of this Service.
 */
class ServiceRegistry : public virtual neo::cca::Port
{
public:
	
  virtual ~ServiceRegistry() {}

    /**
     * Add a ServiceProvider that can be asked to produce service Port's
     * for other components to use subsequently.
     * True means success. False means that for some reason, the
     * provider isn't going to function.
     */
    virtual bool addService(const std::string & type, ServiceProvider * portProvider)= 0;

    /** Add a "reusable" service gov.cca.Port for other components to use 
     * subsequently.
     */
    virtual bool addSingletonService(const std::string & type, neo::cca::Port * service)= 0;

    /** Inform the framework that this service Port is no longer to
     * be used, subsequent to this call. This is likely to
     * cause an exception unless all the ports obtained from the
     * previously added services have been released and disconnected.
     */
    virtual void removeService(const std::string & serviceType)= 0;

}; // class ServiceRegistry

}  // end namespace ports
}  // end namespace cca
}  // end namespace neo

#endif // ServiceRegistry_hh_seen
