#ifndef neo_support_MPISetup_hh_seen
#define neo_support_MPISetup_hh_seen

namespace neo {
namespace support {

/**
 * Implementation that can be reused by driver writers.
 * Independent of Ccafe internals.
 */
class MPISetup
{

private:

	neo::cca::Services *ms;
	neo::cca::AbstractFramework *naf;
	neo::cca::ports::MPIService *mpis;
	neo::cca::ports::MPIBorrow *mpib;
	neo::cca::ports::ServiceRegistry *sr;
	bool finalized;

public:

	MPISetup();
	~MPISetup();

	/** Create and add to the framework MPIService and MPIBorrow
	 * support services. This will appear in the frame as an
	 * MPISetup component. MPI_Init must have been called before
	 * this is called.
	 * @param borrowComm  the shared communicator 
	 *   for those using MPIBorrow.
	 * @param dupComm  the communicator to duplicate 
	 *   for those using MPIService.
	 * @param naf The frame into which the services will be added.
	 */
	void initialize(MPI_Comm borrowComm, MPI_Comm dupComm, neo::cca::AbstractFramework *naf);

	/**
	 * Shutdown the previous mpi-related services.
	 * @param reclaim if reclaim true, try to release communicator
	 * resources allocated in MPIService support.
	 * Otherwise, lose them.
	 */
	void finalize(bool reclaim); 

};

}   // end namespace support
}   // end namespace neo

#endif // neo_support_MPISetup_hh_seen
