#ifndef neo_support_helpers_h_seen
#define neo_support_helpers_h_seen
#include <map>
#include <string>
// requires neocca.hh
// requires neoports.hh

namespace neo {
namespace support {
namespace helpers {

void
setParamsFromString(neo::cca::TypeMap_shared tm, std::map< std::string, std::string > & values);

void 
setParameters(const std::string compName, const std::string port, neo::cca::ComponentID_shared comp, neo::cca::ports::BuilderService *bs, neo::cca::Services *services, std::map< std::string, std::string > & values);

int
invokeGo( const std::string comp, const std::string port, neo::cca::ComponentID_shared target, neo::cca::Services *services, neo::cca::ports::BuilderService *bs);

/** given a string name of a primitive data type, return the enumerated type. */
::neo::cca::Type
typeFromString( const ::std::string &typeName);

/**
 * put a value in by type after parsing. array types unsupported.
 * @param key the key to be stored
 * @param dt the type of the value for the key.
 * @param v the value to be parsed according to dt.
 * @param tm the map to store the key/value pair in.
 */
void
transformString(const ::std::string & key, ::neo::cca::Type dt, const ::std::string & v, ::neo::cca::TypeMap_shared tm);

/** set a value from strings.
 * @param t the map to be put into.
 * @param key the key to be used.
 * @param vtype the string name for the type.
 * @param val the value to be parsed into a type matching vtype.
 */
int
putValueByStrings( ::neo::cca::TypeMap_shared t, const ::std::string & key, const ::std::string &vtype, const ::std::string & val);

/** given a type, return the string equivalent. */
const std::string 
typeToName( ::neo::cca::Type t);

/** given a map and key, return the string form of the type
 * the key indexes.
 */
::std::string
stringType( ::neo::cca::TypeMap_shared t, const ::std::string &key);

/** given a map and key, return the string form of the value.
 */
::std::string 
stringValue( ::neo::cca::TypeMap_shared t, const ::std::string &key);

/** print typemap as formated key-value pairs on stdout in sorted key
 * order.
 */
void
dumpTypeMapStdout(::neo::cca::TypeMap_shared t);


}  // end namespace helpers
}  // end namespace support
}  // end namespace neo
#endif // neo_support_helpers_h_seen
