#ifndef __NEOTEST_PARAMETER_H__
#define __NEOTEST_PARAMETER_H__

namespace neo {
namespace test {

 
// Next two classes are private implementation details.
// Most components would just inherit and implement directly
// the ParameterGet/SetListener interfaces.
// We do something funky here just to demonstrate that it
// doesn't have to be inheritance and to test memory management.
class InternalParameterSetListener;
class InternalParameterGetListener;

/**
Uses neo ParameterPortFactory and JPrintfPort
in response to its GoPort. 
*/
class Parameter : public virtual neo::cca::Component, public virtual neo::cca::ComponentRelease, public virtual neo::cca::ports::GoPort {

private:

  neo::cca::Services *myCore;
  neo::cca::ports::JPrintfPort *jpfp;
  neo::cca::ports::ParameterPortFactory *ppf;
  int numtests;

  std::vector< ::neo::cca::TypeMap_shared > pplist;
  std::vector< InternalParameterSetListener *> setListeners;
  std::vector< InternalParameterGetListener *> getListeners;


public:

  Parameter();
  virtual ~Parameter();

  virtual void setServices(neo::cca::Services *cc) throw(neo::cca::Exception);

  /** This generates parameter ports, and removes them. */
  virtual int go();

  virtual void releaseServices(neo::cca::Services *svc) throw(neo::cca::Exception);

};

}   // end namespace test
}   // end namespace neo

#endif //__NEOTEST_PARAMETER_H__
